@@ -1,7 +1,7 @@
 #
 #	Gnu.pm --- The GNU Readline/History Library wrapper module
 #
-#	$Id: Gnu.pm,v 1.73 1999-05-05 02:55:47+09 hayashi Exp $
+#	$Id: Gnu.pm,v 1.76 1999-12-30 14:13:46+09 hayashi Exp $
 #
 #	Copyright (c) 1999 Hiroo Hayashi.  All rights reserved.
 #
@@ -59,7 +59,7 @@ use Carp;
     use DynaLoader;
     use vars qw($VERSION @ISA @EXPORT_OK);
 
-    $VERSION = '1.06';
+    $VERSION = '1.08';
 
     # Term::ReadLine::Gnu::AU makes a function in
     # `Term::ReadLine::Gnu::XS' as a method.
@@ -159,6 +159,10 @@ sub new {
     # set rl_readline_name before .inputrc is read in rl_initialize()
     $Attribs{readline_name} = $name;
 
+    # some version of Perl cause segmentation fault, if XS module
+    # calls setenv() before the 1st assignment to $ENV{}.
+    $ENV{_TRL_DUMMY} = '';
+
     # initialize the GNU Readline Library and termcap library
     $self->initialize();
 
@@ -264,7 +268,8 @@ sub readline {			# should be ReadLine
 
     # add to history buffer
     $self->add_history($line) 
-	if ($self->{MinLength} > 0 && length($line) >= $self->{MinLength});
+	if (defined $self->{MinLength} && $self->{MinLength} > 0
+	    && length($line) >= $self->{MinLength});
 
     return $line;
 }
